Crate request_id_middleware

Crate request_id_middleware 

Structs

ExtractRequestId
This is a custom extractor for Axum that extracts the request id, via the X-Request-Id header. If the X-Request-Id header is present and it’s a valid UUID v7, it returns it. If the X-Request-Id header is present and it’s an invalid UUID v7 (either not an UUID or an UUID v7), it returns a 400 Bad Request error with a specific message. If the X-Request-Id header is not present, it defaults to a newly generated UUID v7.