Structs
- Extract
Request Id - This is a custom extractor for Axum that extracts the request id, via the
X-Request-Idheader. If theX-Request-Idheader is present and it’s a valid UUID v7, it returns it. If theX-Request-Idheader is present and it’s an invalid UUID v7 (either not an UUID or an UUID v7), it returns a 400 Bad Request error with a specific message. If theX-Request-Idheader is not present, it defaults to a newly generated UUID v7.